Contributing
============

This is an Open Source project. Any help, ideas, and Code are welcome. If you want to contribute, feel free and write a PR, or contact me.

Code style
----------

No compromises. Format your code using `Black <https://black.readthedocs.io/en/stable/>`_ before committing.
